@@ -135,9 +135,9 @@ is_close:{is_close}
         message = message.replace('\n', '')
 
         caller = getframeinfo(stack()[1][0])
-        # self.pool.submit(self.__send, message=message, is_close=0, filename=caller.filename, lineno=caller.lineno)
+        self.pool.submit(self.__send, message=message, is_close=0, filename=caller.filename, lineno=caller.lineno)
         # DEBUG
-        self.__send(message=message, is_close=0, filename=caller.filename, lineno=caller.lineno)
+        # self.__send(message=message, is_close=0, filename=caller.filename, lineno=caller.lineno)
 
     def close(self):
         """
